__version__ = "0.2.8"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(HEAD detached at v0.2.8)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'eebe605b5061f94e090aeb0f88f5053a7c0fc828'
__git_head_subject__ = 'Finished Release v0.2.8'
__git_head_message__ = ''
__git_dirty_diff__ = ''
__git_commit_date__ = '2016-12-18 14:33:57'
